@@ -59,11 +59,13 @@ def _cfg_section_to_df(tabname, data, len_prefix):
     data: {'_row_0': {'id': 1, 'Name': 'Doe', 'Firstname': 'John'}, ...}
     """
     # transform "{ROW_PREFIX}n" -> index
-    try:
-        index = [int(ix[len_prefix:]) for ix in data.keys()]
-    except:
-        __import__("pdb").set_trace()
-    df = pd.DataFrame(data.values(), index=index)
+    columns = data.pop("columns", None)
+    index = [int(ix[len_prefix:]) for ix in data.keys()]
+    if not columns:
+        # legacy format without `columns` specifications
+        df = pd.DataFrame(data.values(), index=index)
+    else:
+        df = pd.DataFrame(data.values(), columns=columns.split(","), index=index)
     df = df.replace("", np.nan, regex=False)
     df.columns = [c.replace(":::", "\n") for c in df.columns]
     return df
@@ -261,6 +263,7 @@ class IOMixin:
             df = df.fillna("")
             df2dict = df.T.to_dict()
             config[tabname] = {}  # create a section
+            config[tabname]["columns"] = ",".join(df.columns.tolist())
             for id_, id_data in df2dict.items():
                 # multiline headers are not allowed
                 id_data = {k.replace("\n", ":::"): v for k, v in id_data.items()}
